#
# spec file for package python-service_identity
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oname   service_identity

Name:           python-service_identity
Version:        16.0.0
Release:        lp150.1.3
Summary:        Service identity verification for pyOpenSSL
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/pyca/service_identity
Source0:        https://pypi.io/packages/source/s/%{oname}/%{oname}-%{version}.tar.gz
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pyOpenSSL >= 0.14}
BuildRequires:  %{python_module pyasn1-modules}
BuildRequires:  %{python_module pyasn1}
BuildRequires:  %{python_module setuptools}
# Documentation
BuildRequires:  %{python_module Sphinx}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros

Requires:       python-attrs
Requires:       python-pyOpenSSL >= 0.14
Requires:       python-pyasn1
Requires:       python-pyasn1-modules
Requires:       python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%python_subpackages

%description
service_identity aspires to give you all the tools you need for
verifying whether a certificate is valid for the intended purposes.

In the simplest case, this means host name verification. However,
service_identity implements RFC 6125 fully and plans to add other
relevant RFCs too.

%prep
%setup -q -n %{oname}-%{version}

%build
%python_build

# make man and documentation
cd docs
make man singlehtml

%install
%python_install

# install man
install -Dm 0644 docs/_build/man/%{oname}.1 %{buildroot}%{_mandir}/man1/%{oname}.1
%python_clone %{buildroot}%{_mandir}/man1/%{oname}.1
%fdupes %{buildroot}%{_prefix}

%files %{python_files}
%defattr(-,root,root,-)
%doc AUTHORS.rst LICENSE README.rst docs/_build/singlehtml/index.html
%{_mandir}/man1/*-%{python_bin_suffix}.1%{?ext_man}
%python3_only %{_mandir}/man1/%{oname}.1%{?ext_man}
%{python_sitelib}/%{oname}
%{python_sitelib}/%{oname}-%{version}-py%{py_ver}.egg-info

%changelog
* Sat Jul  1 2017 okurz@suse.com
- Convert to singlespec
* Thu Jun  2 2016 jacobwinski@gmail.com
- Update to 16.0.0:
  * Changes:
    +  Officially support Python 3.5.
    +  service_identity.SubjectAltNameWarning is now raised if the server certicate lacks a proper SubjectAltName. [#9]
    +  Add a __str__ method to VerificationError.
    +  Port from characteristic to its spiritual successor attrs.
  * Backward-incompatible changes:
    +  Python 3.3 and 2.6 aren't supported anymore. They may work by chance but any effort to keep them working has ceased.
    +  pyOpenSSL versions older than 0.14 are not tested anymore. They don't even build with recent OpenSSL versions.
- Update spec file with new upstream package requirements.
* Tue Jul 21 2015 nemysis@gmx.ch
- Change URL
- Use %%{oname} instead of service_identity
- Add BuildRequires for python-Sphinx for Documentation
- Change Description
- Change Documentation add index.html
- Add Man Page
* Thu Jul 16 2015 jacobwinski@gmail.com
- update pkg description to reflect upstream
- rm warnings in description about this pkg being alpha / possibly broken
* Thu Jul 16 2015 jacobwinski@gmail.com
- alphabetize BuildRequires & Requires
- remove no longer needed commented out test fail workaround
* Thu Jul 16 2015 jacobwinski@gmail.com
- update to 14.0.0:
  * update spec file with new requirements per instructions by upstream
  * update spec file comment out no longer needed test fail workaround
  * upstream changes:
    + Switch to year-based version numbers.
    + Port to characteristic 14.0 (get rid of deprecation warnings).
    + Package docs with sdist.
-update to 1.0.0:
  * Backward-incompatible changes:
    + Drop support for Python 3.2. There is no justification to add complexity and unnecessary function calls for a Python version that nobody uses.
  * changes:
    + Move into the Python Cryptography Authority’s GitHub account.
    + Move exceptions into service_identity.exceptions so tracebacks don’t contain private module names.
    + Promoting to stable since Twisted 14.0 is optionally depending on service_identity now.
    + Use characteristic instead of a home-grown solution.
    + idna 0.6 did some backward-incompatible fixes that broke Python 3 support. This has been fixed now therefore service_identity only works with idna 0.6 and later. Unfortunately since idna doesn’t offer version introspection, service_identity can’t warn about it.
* Thu May 15 2014 hpj@urpla.net
- version 0.2: initial build
